@@ -2,9 +2,13 @@
 //!
 //! By default the terminal expects a [code page 437](https://dwarffortresswiki.org/Tileset_repository)
 //! texture with 16x16 characters. New font textures can be placed in the `assets/textures`
-//! directory and they will be loaded when the application runs. The terminal font can be changed by
-//! modifying the [TerminalFont] component on the terminal entity. Font data can be read from the
-//! [TerminalFonts] resource.
+//! directory and they will be loaded when the application runs.
+//!
+//! The terminal can handle non-square fonts but only if using [TileScaling::Pixels](super::TileScaling::Pixels).
+//! TileScaling is a component on the terminal that can be changed during construction or at runtime.
+//!
+//! The terminal font can be changed by modifying the [TerminalFont] component on the terminal entity.
+//! Font data can be read from the [TerminalFonts] resource.
 //!
 //! Texture sprites are mapped to glyphs via [GlyphMapping](super::glyph_mapping::GlyphMapping).
 //!
@@ -39,7 +43,7 @@ use std::{collections::HashMap, path::PathBuf};
 // https://github.com/bevyengine/bevy/pull/2310
 use std::fs;
 
-use super::plugin::AppState;
+use super::plugin::TerminalAssetLoadState;
 
 /// Terminal component that determines which texture is rendered by the terminal.
 ///
@@ -50,7 +54,7 @@ pub struct TerminalFont {
     /// The color on the texture that should be treated as the background
     clip_color: Color,
     tex_handle: Handle<Texture>,
-    pixels_per_unit: u32,
+    pixels_per_unit: UVec2,
     //tile_count: UVec2,
 }
 impl Default for TerminalFont {
@@ -110,8 +114,8 @@ impl TerminalFont {
         self.clip_color = color;
     }
 
-    /// How many vertical pixels for a single character.
-    pub fn pixels_per_unit(&self) -> u32 {
+    /// How many pixels for a single character.
+    pub fn pixels_per_unit(&self) -> UVec2 {
         self.pixels_per_unit
     }
 
@@ -130,7 +134,7 @@ impl TerminalFont {
         let texture = textures.get(tex_handle.clone_weak()).unwrap();
         let tex_size = UVec2::new(texture.size.width, texture.size.height);
         let tile_count = UVec2::new(16, 16);
-        let pixels_per_tile = (tex_size / tile_count).y;
+        let pixels_per_tile = tex_size / tile_count;
 
         TerminalFont {
             name: String::from(name),
@@ -185,11 +189,11 @@ impl Plugin for TerminalFontPlugin {
         app.init_resource::<LoadingTerminalTextures>()
             .init_resource::<TerminalFonts>()
             .add_system_set(
-                SystemSet::on_enter(AppState::AssetsLoading)
+                SystemSet::on_enter(TerminalAssetLoadState::AssetsLoading)
                     .with_system(terminal_load_fonts.system()),
             )
             .add_system_set(
-                SystemSet::on_update(AppState::AssetsLoading)
+                SystemSet::on_update(TerminalAssetLoadState::AssetsLoading)
                     .with_system(terminal_check_loading_fonts.system()),
             );
     }
@@ -225,8 +229,8 @@ fn load_built_in_fonts(fonts: &mut TerminalFonts, textures: &mut ResMut<Assets<T
 fn terminal_check_loading_fonts(
     asset_server: Res<AssetServer>,
     loading: Res<LoadingTerminalTextures>,
-    mut textures: ResMut<Assets<Texture>>,
-    mut state: ResMut<State<AppState>>,
+    textures: ResMut<Assets<Texture>>,
+    mut state: ResMut<State<TerminalAssetLoadState>>,
     mut fonts: ResMut<TerminalFonts>,
 ) {
     let loaded = loading.0.as_ref();
@@ -253,13 +257,15 @@ fn terminal_check_loading_fonts(
             {
                 let name = path.file_name().unwrap().to_str().unwrap();
 
-                let font = TerminalFont::from_texture(name, handle, &mut textures);
+                let font = TerminalFont::from_texture(name, handle, &textures);
 
                 fonts.add(font);
             }
         }
 
-        state.set(AppState::AssetsDoneLoading).unwrap();
+        state
+            .set(TerminalAssetLoadState::AssetsDoneLoading)
+            .unwrap();
     }
 }
 
